==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/bibtexentryfield.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <bibtexencoder.h>
#include "bibtexentryfield.h"

BibTeXEntryField::BibTeXEntryField( FieldType fieldType, const QString &value, QObject *parent, const char *name ) : QObject( parent, name ), m_fieldType( fieldType ), m_value( BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, fieldType ) ), m_key( fieldTypeToString( fieldType ) )
{
    // TODO
}

BibTeXEntryField::BibTeXEntryField( const QString &key, const QString &value, QObject *parent, const char *name ) : QObject( parent, name ), m_fieldType( fieldTypeFromString( key ) ), m_value( BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, m_fieldType ) ), m_key( key )
{
    // TODO
}

BibTeXEntryField::BibTeXEntryField( BibTeXEntryField* other )
{
    m_fieldType = other->m_fieldType;
    m_key = other->m_key;
    m_value = other->m_value;
}

BibTeXEntryField::~BibTeXEntryField()
{
    // TODO
}

QString BibTeXEntryField::value()
{
    return m_value;
}

void BibTeXEntryField::setValue( const QString& value )
{
    m_value = BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, m_fieldType );
}

QString BibTeXEntryField::key()
{
    return m_key;
}

BibTeXEntryField::FieldType BibTeXEntryField::fieldType()
{
    return m_fieldType;
}

QString BibTeXEntryField::fieldTypeToString( const FieldType fieldType )
{
    switch ( fieldType )
    {
    case ftAbstract:
        return QString( "abstract" );
    case ftAddress:
        return QString( "address" );
    case ftAnnote:
        return QString( "annote" );
    case ftAuthor:
        return QString( "author" );
    case ftBookTitle:
        return QString( "booktitle" );
    case ftChapter:
        return QString( "chapter" );
    case ftCrossRef:
        return QString( "crossref" );
    case ftEdition:
        return QString( "edition" );
    case ftEditor:
        return QString( "editor" );
    case ftHowPublished:
        return QString( "howpublished" );
    case ftInstitution:
        return QString( "institution" );
    case ftISBN:
        return QString( "isbn" );
    case ftISSN:
        return QString( "issn" );
    case ftJournal:
        return QString( "journal" );
    case ftKey:
        return QString( "key" );
    case ftMonth:
        return QString( "month" );
    case ftNote:
        return QString( "note" );
    case ftNumber:
        return QString( "number" );
    case ftOrganization:
        return QString( "organization" );
    case ftPages:
        return QString( "pages" );
    case ftPublisher:
        return QString( "publisher" );
    case ftSeries:
        return QString( "series" );
    case ftSchool:
        return QString( "school" );
    case ftTitle:
        return QString( "title" );
    case ftType:
        return QString( "type" );
    case ftURL:
        return QString( "url" );
    case ftVolume:
        return QString( "volume" );
    case ftYear:
        return QString( "year" );
    default:
        return QString( "unknown" );
    }
}

BibTeXEntryField::FieldType BibTeXEntryField::fieldTypeFromString( const QString & fieldTypeString )
{
    QString fieldTypeStringLower = fieldTypeString.lower();

    if ( fieldTypeStringLower.compare( "abstract" ) == 0 )
        return ftAbstract;
    else if ( fieldTypeStringLower.compare( "address" ) == 0 )
        return ftAddress;
    else if ( fieldTypeStringLower.compare( "annote" ) == 0 )
        return ftAnnote;
    else if ( fieldTypeStringLower.compare( "author" ) == 0 )
        return ftAuthor;
    else if ( fieldTypeStringLower.compare( "booktitle" ) == 0 )
        return ftBookTitle;
    else if ( fieldTypeStringLower.compare( "chapter" ) == 0 )
        return ftChapter;
    else if ( fieldTypeStringLower.compare( "crossref" ) == 0 )
        return ftCrossRef;
    else if ( fieldTypeStringLower.compare( "edition" ) == 0 )
        return ftEdition;
    else if ( fieldTypeStringLower.compare( "editor" ) == 0 )
        return ftEditor;
    else if ( fieldTypeStringLower.compare( "howpublished" ) == 0 )
        return ftHowPublished;
    else if ( fieldTypeStringLower.compare( "institution" ) == 0 )
        return ftInstitution;
    else if ( fieldTypeStringLower.compare( "isbn" ) == 0 )
        return ftISBN;
    else if ( fieldTypeStringLower.compare( "issn" ) == 0 )
        return ftISSN;
    else if ( fieldTypeStringLower.compare( "journal" ) == 0 )
        return ftJournal;
    else if ( fieldTypeStringLower.compare( "key" ) == 0 )
        return ftKey;
    else if ( fieldTypeStringLower.compare( "month" ) == 0 )
        return ftMonth;
    else if ( fieldTypeStringLower.compare( "note" ) == 0 )
        return ftNote;
    else if ( fieldTypeStringLower.compare( "number" ) == 0 )
        return ftNumber;
    else if ( fieldTypeStringLower.compare( "organization" ) == 0 )
        return ftOrganization;
    else if ( fieldTypeStringLower.compare( "pages" ) == 0 )
        return ftPages;
    else if ( fieldTypeStringLower.compare( "publisher" ) == 0 )
        return ftPublisher;
    else if ( fieldTypeStringLower.compare( "series" ) == 0 )
        return ftSeries;
    else if ( fieldTypeStringLower.compare( "school" ) == 0 )
        return ftSchool;
    else if ( fieldTypeStringLower.compare( "title" ) == 0 )
        return ftTitle;
    else if ( fieldTypeStringLower.compare( "type" ) == 0 )
        return ftType;
    else if ( fieldTypeStringLower.compare( "url" ) == 0 )
        return ftURL;
    else if ( fieldTypeStringLower.compare( "volume" ) == 0 )
        return ftVolume;
    else if ( fieldTypeStringLower.compare( "year" ) == 0 )
        return ftYear;
    else
        return ftUnknown;
}

#include "bibtexentryfield.moc"

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/bibtexentryfield.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <bibtexencoder.h>
#include "bibtexentryfield.h"

BibTeXEntryField::BibTeXEntryField( FieldType fieldType, const QString &value, bool isString, QObject *parent, const char *name ) : QObject( parent, name ), m_fieldType( fieldType ), m_value( BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, fieldType ) ), m_key( fieldTypeToString( fieldType ) ), m_isString( isString && BibTeXElement::isSimpleString( value ) )
{
    // TODO
}

BibTeXEntryField::BibTeXEntryField( const QString &key, const QString &value, bool isString, QObject *parent, const char *name ) : QObject( parent, name ), m_fieldType( fieldTypeFromString( key ) ), m_value( BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, m_fieldType ) ), m_key( key ), m_isString( isString && BibTeXElement::isSimpleString( value ) )
{
    // TODO
}

BibTeXEntryField::BibTeXEntryField( BibTeXEntryField* other )
{
    m_fieldType = other->m_fieldType;
    m_key = other->m_key;
    m_value = other->m_value;
    m_isString = other->m_isString;
}

BibTeXEntryField::~BibTeXEntryField()
{
    // TODO
}

QString BibTeXEntryField::value()
{
    return m_value;
}

void BibTeXEntryField::setValue( const QString& value, bool isString )
{
    m_value = BibTeXEncoder::currentBibTeXEncoder() ->decodeSpecialized( value, m_fieldType );
    m_isString = isString && BibTeXElement::isSimpleString( value );
}

QString BibTeXEntryField::key()
{
    return m_key;
}

BibTeXEntryField::FieldType BibTeXEntryField::fieldType()
{
    return m_fieldType;
}

bool BibTeXEntryField::isString()
{
    return m_isString;
}

QString BibTeXEntryField::fieldTypeToString( const FieldType fieldType )
{
    switch ( fieldType )
    {
    case ftAbstract:
        return QString( "abstract" );
    case ftAddress:
        return QString( "address" );
    case ftAnnote:
        return QString( "annote" );
    case ftAuthor:
        return QString( "author" );
    case ftBookTitle:
        return QString( "booktitle" );
    case ftChapter:
        return QString( "chapter" );
    case ftCrossRef:
        return QString( "crossref" );
    case ftEdition:
        return QString( "edition" );
    case ftEditor:
        return QString( "editor" );
    case ftHowPublished:
        return QString( "howpublished" );
    case ftInstitution:
        return QString( "institution" );
    case ftISBN:
        return QString( "isbn" );
    case ftISSN:
        return QString( "issn" );
    case ftJournal:
        return QString( "journal" );
    case ftKey:
        return QString( "key" );
    case ftMonth:
        return QString( "month" );
    case ftNote:
        return QString( "note" );
    case ftNumber:
        return QString( "number" );
    case ftOrganization:
        return QString( "organization" );
    case ftPages:
        return QString( "pages" );
    case ftPublisher:
        return QString( "publisher" );
    case ftSeries:
        return QString( "series" );
    case ftSchool:
        return QString( "school" );
    case ftTitle:
        return QString( "title" );
    case ftType:
        return QString( "type" );
    case ftURL:
        return QString( "url" );
    case ftVolume:
        return QString( "volume" );
    case ftYear:
        return QString( "year" );
    default:
        return QString( "unknown" );
    }
}

BibTeXEntryField::FieldType BibTeXEntryField::fieldTypeFromString( const QString & fieldTypeString )
{
    QString fieldTypeStringLower = fieldTypeString.lower();

    if ( fieldTypeStringLower.compare( "abstract" ) == 0 )
        return ftAbstract;
    else if ( fieldTypeStringLower.compare( "address" ) == 0 )
        return ftAddress;
    else if ( fieldTypeStringLower.compare( "annote" ) == 0 )
        return ftAnnote;
    else if ( fieldTypeStringLower.compare( "author" ) == 0 )
        return ftAuthor;
    else if ( fieldTypeStringLower.compare( "booktitle" ) == 0 )
        return ftBookTitle;
    else if ( fieldTypeStringLower.compare( "chapter" ) == 0 )
        return ftChapter;
    else if ( fieldTypeStringLower.compare( "crossref" ) == 0 )
        return ftCrossRef;
    else if ( fieldTypeStringLower.compare( "edition" ) == 0 )
        return ftEdition;
    else if ( fieldTypeStringLower.compare( "editor" ) == 0 )
        return ftEditor;
    else if ( fieldTypeStringLower.compare( "howpublished" ) == 0 )
        return ftHowPublished;
    else if ( fieldTypeStringLower.compare( "institution" ) == 0 )
        return ftInstitution;
    else if ( fieldTypeStringLower.compare( "isbn" ) == 0 )
        return ftISBN;
    else if ( fieldTypeStringLower.compare( "issn" ) == 0 )
        return ftISSN;
    else if ( fieldTypeStringLower.compare( "journal" ) == 0 )
        return ftJournal;
    else if ( fieldTypeStringLower.compare( "key" ) == 0 )
        return ftKey;
    else if ( fieldTypeStringLower.compare( "month" ) == 0 )
        return ftMonth;
    else if ( fieldTypeStringLower.compare( "note" ) == 0 )
        return ftNote;
    else if ( fieldTypeStringLower.compare( "number" ) == 0 )
        return ftNumber;
    else if ( fieldTypeStringLower.compare( "organization" ) == 0 )
        return ftOrganization;
    else if ( fieldTypeStringLower.compare( "pages" ) == 0 )
        return ftPages;
    else if ( fieldTypeStringLower.compare( "publisher" ) == 0 )
        return ftPublisher;
    else if ( fieldTypeStringLower.compare( "series" ) == 0 )
        return ftSeries;
    else if ( fieldTypeStringLower.compare( "school" ) == 0 )
        return ftSchool;
    else if ( fieldTypeStringLower.compare( "title" ) == 0 )
        return ftTitle;
    else if ( fieldTypeStringLower.compare( "type" ) == 0 )
        return ftType;
    else if ( fieldTypeStringLower.compare( "url" ) == 0 )
        return ftURL;
    else if ( fieldTypeStringLower.compare( "volume" ) == 0 )
        return ftVolume;
    else if ( fieldTypeStringLower.compare( "year" ) == 0 )
        return ftYear;
    else
        return ftUnknown;
}

#include "bibtexentryfield.moc"
